@@ -181,8 +181,8 @@ class FaultDiagnosis():
             name='perturbation_resistant')
         nx.set_node_attributes(T, self.G.type, name='type')
 
-        for switch, opened in zip(initial_condition.keys(), individual):
-            if not opened:
+        for switch, status in zip(initial_condition.keys(), individual):
+            if not status:
                 for pred in list(T.predecessors(switch)):
                     T.remove_edge(pred, switch)
 
@@ -402,10 +402,8 @@ class FaultDiagnosis():
 
         Remove nodes from the graph in a depth first search way to
         propagate the perturbation.
-        Nodes are not deleted if perturbation resistant.
-        Moreover, valves are not deleted if encountered
-        during the propagation of a the perturbation.
-        They are deleted, instead, if object of node deletion themselves.
+        Nodes are not deleted if at the beginning of the cascade, when resistant
+        to the origin of the perturbation.
 
         :param str node: the id of the node to remove.
         :param nx.DiGraph graph: graph on which to apply the node deletion
@@ -426,7 +424,7 @@ class FaultDiagnosis():
         logging.debug('Visited: %s', visited)
         logging.debug('Node: %s', node)
 
-        if origin in graph.perturbation_resistant[node]:
+        if origin in graph.perturbation_resistant[node] and len(visited) == 1:
             logging.debug('Node %s visited, fault resistant node', node)
             logging.debug('Perturbation origin: %s', origin)
             return visited, broken_nodes
@@ -544,7 +542,7 @@ class FaultDiagnosis():
         """
 
         Perturbation simulator, actually applying the perturbation
-        to all the nodes affected by the perturbation.
+        to all the nodes.
         The optimizer is run if any switch is present, and edges connecting
         its predecessors are removed if the switch state is set to 'False'.
 
@@ -603,9 +601,9 @@ class FaultDiagnosis():
                 np.not_equal(initial_condition_sw, final_condition_sw)))
 
         init_open_edges = {}
-        for sw, closed in self.G.init_status.items():
-            if not closed:
-                logging.debug('Opened switch %s in initial configuration', sw)
+        for sw, status_sw in self.G.init_status.items():
+            if not status_sw:
+                logging.debug('False switch %s in initial configuration', sw)
                 init_open_edges[sw] = {}
                 for pred in list(self.G.predecessors(sw)):
                     # if final config is closed for this switch I memorize it
@@ -622,10 +620,10 @@ class FaultDiagnosis():
             'outdegree_centrality', 'degree_centrality'])
 
         if self.G.switches:
-            for sw, status in best.items():
+            for sw, status_sw in best.items():
                 if flips[sw]:
 
-                    if not status:
+                    if not status_sw:
                         logging.debug('Switch %s finally False, first True',
                         sw)
                         for pre in list(self.G.predecessors(sw)):
