@@ -1405,9 +1405,9 @@ class GeneralGraph(nx.DiGraph):
             if d['father_condition'] == 'SINGLE']
 
         if status == 'initial':
-            open_sw = [k for k, v in self.init_status.items() if not v]
+            status_sw = [k for k, v in self.init_status.items() if not v]
             edges_no_init = []
-            for sw in open_sw:
+            for sw in status_sw:
                 for pred in list(self.predecessors(sw)):
                     edges_no_init.append((pred,sw))
 
